@@ -12,7 +12,6 @@
 #include <entitytreemodel.h>
 
 #include <KCalendarCore/Incidence>
-#include <KCalendarCore/Attendee>
 // #include <email.h>
 
 #include <identitymanager.h>
@@ -25,12 +24,11 @@ class Q_DECL_HIDDEN CalFilterPartStatusProxyModel::Private
 public:
     explicit Private()
         : mIdentityManager(KIdentityManagement::IdentityManager::self())
-        , mFilterVirtual(false)
     {
     }
 
     QList<KCalendarCore::Attendee::PartStat> mBlockedStatusList;
-    KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
+    KIdentityManagement::IdentityManager * const mIdentityManager;
     bool mFilterVirtual = false;
 };
 
