@@ -14,7 +14,6 @@
 #include <KActionCollection>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Journal>
-#include <kcalendarcore/todo.h>
 #include <KLocalizedString>
 
 #include <QItemSelectionModel>
@@ -521,7 +520,7 @@ public:
     QItemSelectionModel *mItemSelectionModel = nullptr;
     QHash<StandardCalendarActionManager::Type, QAction *> mActions;
     QSet<StandardCalendarActionManager::Type> mInterceptedActions;
-    StandardCalendarActionManager *mParent = nullptr;
+    StandardCalendarActionManager *const mParent;
 };
 
 Akonadi::StandardCalendarActionManager::StandardCalendarActionManager(KActionCollection *actionCollection, QWidget *parent)
